OC.L10N.register(
    "contacts",
    {
    "Contacts" : "Contacte",
    "Download" : "Descarcă",
    "Share with users or groups" : "Partajează cu utilizatori sau grupuri",
    "Delete" : "Șterge",
    "can edit" : "poate edita",
    "Address book name" : "Numele listă de contacte",
    "Import" : "Importă",
    "The selected image is too big (max 1MB)" : "Imaginea selectată este prea mare (maxim 1 MB)",
    "No contacts in here" : "Niciun contact aici",
    "Name" : "Nume",
    "Organization" : "Organizație",
    "Title" : "Titlu",
    "Add field ..." : "Adaugă câmp ...",
    "No search result for {query}" : "Niciun rezultat pentru {query}",
    "Postal code" : "Codul poștal",
    "City" : "Oraș",
    "State or province" : "Județ sau provincie",
    "Country" : "Țară",
    "Address" : "Adresă",
    "(new group)" : "(grup nou)",
    "Last name" : "Nume",
    "First name" : "Prenume",
    "All contacts" : "Toate contactele",
    "Not grouped" : "Negrupate",
    "New contact" : "Contact nou ",
    "{addressbook} shared by {owner}" : "{addressbook} partajat de {owner}",
    "No contacts in file. Only VCard files are allowed." : "Niciun contact în fișier. Doar fișiere VCard sunt suportate.",
    "Nickname" : "Pseudonim",
    "Notes" : "Notă",
    "Website" : "Website",
    "Federated Cloud ID" : "Federated Cloud ID",
    "Home" : "Acasă",
    "Work" : "Serviciu",
    "Other" : "Altele",
    "Groups" : "Grupuri",
    "Birthday" : "Zi de naștere",
    "Email" : "Email",
    "Instant messaging" : "Mesagerie instantă",
    "Phone" : "Telefon",
    "Mobile" : "Mobil",
    "Fax" : "Fax",
    "Fax home" : "Fax - acasă",
    "Fax work" : "Fax - serviciu",
    "Pager" : "Pager",
    "Voice" : "Voce",
    "Settings" : "Setări"
},
"nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");
